@@ -79,8 +79,8 @@ define usevfork 'false'
 define d_libname_unique 'undef'
 define d_vms_case_sensitive_symbols 'undef'
 define dl_so_eq_ext 'define'
-# not used but tested for in ext/Config/t/XSConfig.t!
-define hash_func ''
+# tested for in several places (ext/Config/t/XSConfig.t, t/op/hashflood)
+define hash_func 'FNV1A' # cperl
 define c ''
 define d_bsd 'undef'
 define d_eunice 'undef'
@@ -159,14 +159,14 @@ define d_nv_zero_is_allbits_zero 'define'
 define d_stdio_stream_array 'undef'
 define d_faststdio 'undef'
 define d_libm_lib_version 'undef'
-define d_localtime_r_needs_tzset 'undef'
+define d_localtime_r_needs_tzset 'define'
 define signal_t 'void'
 define d_portable 'define'
 define d_voidtty 'define'
 define d_semctl_semid_ds 'define'
 define d_semctl_semun 'define'
+define default_inc_excludes_dot 'undef'
 
-define d_msg 'undef'
 define d_msg_ctrunc 'undef'
 define d_msg_dontroute 'undef'
 define d_msg_oob 'undef'
@@ -176,6 +176,11 @@ define d_msg_proxy 'undef'
 define d_procselfexe 'undef'
 define procselfexe '""'
 
+define sGMTIME_max '2147483647'
+define sGMTIME_min '-2147483648'
+define sLOCALTIME_max '2147483647'
+define sLOCALTIME_min '-2147483648'
+
 # These should be in modules?
 define netdb_hlen_type 'socklen_t'
 define netdb_host_type 'const void *'
@@ -191,51 +196,6 @@ define d_ndbm_h_uses_prototypes 'define'
 define d_gdbm_ndbm_h_uses_prototypes 'define'
 define d_gdbmndbm_h_uses_prototypes 'define'
 
-# Non-testable printf formats; must be hinted
-define d_PRIEUldbl 'undef'
-define d_PRIFUldbl 'undef'
-define d_PRIGUldbl 'undef'
-define d_PRIXU64 'undef'
-define d_PRId64 'undef'
-define d_PRIeldbl 'undef'
-define d_PRIfldbl 'undef'
-define d_PRIgldbl 'undef'
-define d_PRIi64 'undef'
-define d_PRIo64 'undef'
-define d_PRIu64 'undef'
-define d_PRIx64 'undef'
-define d_SCNfldbl 'undef'
-define sGMTIME_max '2147483647'
-define sGMTIME_min '-2147483648'
-define sLOCALTIME_max '2147483647'
-define sLOCALTIME_min '-2147483648'
-define sPRIEUldbl '"LE"'
-define sPRIFUldbl '"LF"'
-define sPRIGUldbl '"LG"'
-define sPRIXU64 '"LX"'
-define sPRId64 '"Ld"'
-define sPRIeldbl '"Le"'
-define sPRIfldbl '"Lf"'
-define sPRIgldbl '"Lg"'
-define sPRIi64 '"Li"'
-define sPRIo64 '"Lo"'
-define sPRIu64 '"Lu"'
-define sPRIx64 '"Lx"'
-define sSCNfldbl '"Lf"'
-define nvEUformat '"E"'
-define nvFUformat '"F"'
-define nvGUformat '"G"'
-define nveformat '"e"'
-define nvfformat '"f"'
-define nvgformat '"g"'
-define uvXUformat '"lX"'
-define uvoformat '"lo"'
-define uvuformat '"lu"'
-define uvxformat '"lx"'
-define uidformat '"lu"'
-define ivdformat '"ld"'
-define gidformat '"lu"'
-
 # These probably affect something in some cases but we don't test them
 define afs 'false'
 define afsroot '/afs'
